Class: Pry::Shell::IO::Input
Instance Method Summary collapse
- #completion_proc ⇒ Object
-
#completion_proc=(val) ⇒ Object
Assigns the ‘completion_proc` given by the pry instance from the client slide.
- #drb_thread ⇒ Object
- #readline(prompt) ⇒ Object
Methods inherited from Base
Constructor Details
This class inherits a constructor from Pry::Shell::IO::Base
Instance Method Details
#completion_proc ⇒ Object
33 34 35 |
# File 'lib/pry/shell/io/input.rb', line 33 def completion_proc object.completion_proc if object.respond_to?(:completion_proc) end |
#completion_proc=(val) ⇒ Object
Assigns the ‘completion_proc` given by the pry instance from the client slide.
29 30 31 |
# File 'lib/pry/shell/io/input.rb', line 29 def completion_proc=(val) object.completion_proc = val if object.respond_to?(:completion_proc=) end |
#drb_thread ⇒ Object
23 24 25 |
# File 'lib/pry/shell/io/input.rb', line 23 def drb_thread @drb_thread ||= Thread.current end |